@@ -520,7 +520,7 @@ class TableAlias(Expression):
 
 
 class Column(Condition):
-    arg_types = {"this": False, "table": False}
+    arg_types = {"this": True, "table": False}
 
     @property
     def table(self):
@@ -592,7 +592,12 @@ class Partition(Expression):
 
 
 class Group(Expression):
-    arg_types = {"expressions": True}
+    arg_types = {
+        "expressions": False,
+        "grouping_sets": False,
+        "cube": False,
+        "rollup": False,
+    }
 
 
 class Lambda(Expression):
@@ -721,7 +726,7 @@ class Table(Expression):
 
 
 class Tuple(Expression):
-    arg_types = {"expressions": True}
+    arg_types = {"expressions": False}
 
 
 class Subqueryable:
@@ -1332,6 +1337,7 @@ class Subquery(DerivedTable):
     arg_types = {
         "this": True,
         "alias": False,
+        "joins": False,
         "order": False,
         "limit": False,
         "offset": False,
@@ -1350,6 +1356,7 @@ class Subquery(DerivedTable):
 class TableSample(Expression):
     arg_types = {
         "this": True,
+        "method": False,
         "bucket_numerator": False,
         "bucket_denominator": False,
         "bucket_field": False,
@@ -1779,6 +1786,7 @@ class ArrayContains(Func):
 
 class ArrayFilter(Func):
     arg_types = {"this": True, "expression": True}
+    _sql_names = ["FILTER", "ARRAY_FILTER"]
 
 
 class ArraySize(Func):
