@@ -404,6 +404,8 @@ class Generator:
 
     def tablesample_sql(self, expression):
         this = self.sql(expression, "this")
+        method = self.sql(expression, "method")
+        method = f" {method.upper()} " if method else ""
         numerator = self.sql(expression, "bucket_numerator")
         denominator = self.sql(expression, "bucket_denominator")
         field = self.sql(expression, "bucket_field")
@@ -414,7 +416,7 @@ class Generator:
         rows = self.sql(expression, "rows")
         rows = f"{rows} ROWS" if rows else ""
         size = self.sql(expression, "size")
-        return f"{this} TABLESAMPLE({bucket}{percent}{rows}{size})"
+        return f"{this} TABLESAMPLE{method}({bucket}{percent}{rows}{size})"
 
     def tuple_sql(self, expression):
         return f"({self.expressions(expression, flat=True)})"
@@ -438,7 +440,18 @@ class Generator:
         return f"{self.seg('FROM')} {expressions}"
 
     def group_sql(self, expression):
-        return self.op_expressions("GROUP BY", expression)
+        group_by = self.op_expressions("GROUP BY", expression)
+        grouping_sets = self.expressions(expression, key="grouping_sets", indent=False)
+        grouping_sets = (
+            f"{self.seg('GROUPING SETS')} {self.wrap(grouping_sets)}"
+            if grouping_sets
+            else ""
+        )
+        cube = self.expressions(expression, key="cube", indent=False)
+        cube = f"{self.seg('CUBE')} {self.wrap(cube)}" if cube else ""
+        rollup = self.expressions(expression, key="rollup", indent=False)
+        rollup = f"{self.seg('ROLLUP')} {self.wrap(rollup)}" if rollup else ""
+        return f"{group_by}{grouping_sets}{cube}{rollup}"
 
     def having_sql(self, expression):
         this = self.indent(self.sql(expression, "this"))
@@ -556,13 +569,16 @@ class Generator:
 
     def subquery_sql(self, expression):
         alias = self.sql(expression, "alias")
-        alias = f" AS {alias}" if alias else ""
-        order = self.sql(expression, "order")
-        limit = self.sql(expression, "limit")
-        offset = self.sql(expression, "offset")
-        if self.pretty:
-            return f"{self.wrap(expression)}{alias}{order}{limit}{offset}"
-        return f"({self.sql(expression, 'this')}){alias}{order}{limit}{offset}"
+
+        return csv(
+            self.wrap(expression),
+            f" AS {alias}" if alias else "",
+            *[self.sql(sql) for sql in expression.args.get("joins", [])],
+            self.sql(expression, "order"),
+            self.sql(expression, "limit"),
+            self.sql(expression, "offset"),
+            sep="",
+        )
 
     def qualify_sql(self, expression):
         this = self.indent(self.sql(expression, "this"))
@@ -850,7 +866,7 @@ class Generator:
             self.sql(expression, "format"), self.time_mapping, self.time_trie
         )
 
-    def expressions(self, expression, key=None, flat=False):
+    def expressions(self, expression, key=None, flat=False, indent=True):
         # pylint: disable=cell-var-from-loop
         expressions = expression.args.get(key or "expressions")
 
@@ -861,13 +877,15 @@ class Generator:
             return ", ".join(self.sql(e) for e in expressions)
 
         expressions = self.sep(", ").join(self.sql(e) for e in expressions)
-        return self.indent(expressions, skip_first=False)
+        if indent:
+            return self.indent(expressions, skip_first=False)
+        return expressions
 
     def op_expressions(self, op, expression, flat=False):
         expressions_sql = self.expressions(expression, flat=flat)
         if flat:
             return f"{op} {expressions_sql}"
-        return f"{self.seg(op)}{self.sep()}{expressions_sql}"
+        return f"{self.seg(op)}{self.sep() if expressions_sql else ''}{expressions_sql}"
 
     def set_operation(self, expression, op):
         this = self.sql(expression, "this")
