@@ -68,6 +68,8 @@ class Parser:
         TokenType.SOME: exp.Any,
     }
 
+    SINGLE_TOKENS = set(Tokenizer.SINGLE_TOKENS.values())
+
     ID_VAR_TOKENS = {
         TokenType.VAR,
         TokenType.ASC,
@@ -119,6 +121,7 @@ class Parser:
         TokenType.CURRENT_DATE,
         TokenType.CURRENT_TIMESTAMP,
         TokenType.EXTRACT,
+        TokenType.FILTER,
         TokenType.OFFSET,
         TokenType.PRIMARY_KEY,
         TokenType.REPLACE,
@@ -689,14 +692,6 @@ class Parser:
             this=values,
         )
 
-    def _parse_values(self):
-        if not self._match(TokenType.VALUES):
-            return None
-
-        return self.expression(
-            exp.Values, expressions=self._parse_csv(self._parse_value)
-        )
-
     def _parse_value(self):
         self._match_l_paren()
         expressions = self._parse_csv(self._parse_conjunction)
@@ -779,13 +774,6 @@ class Parser:
         )
 
     def _parse_select(self):
-        this = self._parse_values()
-
-        if self._match(TokenType.L_PAREN):
-            this = self._parse_table()
-            self._match_r_paren()
-            this = self._parse_subquery(this)
-
         if self._match(TokenType.SELECT):
             hint = self._parse_hint()
             all_ = self._match(TokenType.ALL)
@@ -804,7 +792,7 @@ class Parser:
                 distinct=distinct,
                 expressions=expressions,
                 **{
-                    "from": this or self._parse_from(),
+                    "from": self._parse_from(),
                     "laterals": self._parse_laterals(),
                     "joins": self._parse_joins(),
                     "where": self._parse_where(),
@@ -818,14 +806,30 @@ class Parser:
                     "offset": self._parse_offset(),
                 },
             )
+        elif self._match(TokenType.L_PAREN):
+            this = self._parse_table()
+            if isinstance(this, exp.Subquery):
+                joins = self._parse_joins()
+                this.set("joins", joins)
+            self._match_r_paren()
+            this = self._parse_subquery(this)
+        elif self._match(TokenType.VALUES):
+            this = self.expression(
+                exp.Values, expressions=self._parse_csv(self._parse_value)
+            )
+        else:
+            this = None
 
         return self._parse_set_operations(this)
 
     def _parse_subquery(self, this):
+        alias = self._parse_table_alias()
+        if isinstance(this, exp.Select):
+            return self.expression(exp.Subquery, this=this, alias=alias)
         return self.expression(
             exp.Subquery,
             this=this,
-            alias=self._parse_table_alias(),
+            alias=alias,
             order=self._parse_order(),
             limit=self._parse_limit(),
             offset=self._parse_offset(),
@@ -905,9 +909,7 @@ class Parser:
         if self._match(TokenType.ON):
             kwargs["on"] = self._parse_conjunction()
         elif self._match(TokenType.USING):
-            self._match_l_paren()
-            kwargs["using"] = self._parse_csv(self._parse_id_var)
-            self._match_r_paren()
+            kwargs["using"] = self._parse_wrapped_id_vars()
 
         return self.expression(exp.Join, **kwargs)
 
@@ -976,6 +978,7 @@ class Parser:
         if not self._match(TokenType.TABLE_SAMPLE):
             return this
 
+        method = self._parse_var()
         bucket_numerator = None
         bucket_denominator = None
         bucket_field = None
@@ -1006,6 +1009,7 @@ class Parser:
         return self.expression(
             exp.TableSample,
             this=this,
+            method=method,
             bucket_numerator=bucket_numerator,
             bucket_denominator=bucket_denominator,
             bucket_field=bucket_field,
@@ -1023,9 +1027,29 @@ class Parser:
         if not self._match_by(TokenType.GROUP):
             return None
         return self.expression(
-            exp.Group, expressions=self._parse_csv(self._parse_conjunction)
+            exp.Group,
+            expressions=self._parse_csv(self._parse_conjunction),
+            grouping_sets=self._parse_grouping_sets(),
+            cube=self._match(TokenType.CUBE) and self._parse_wrapped_id_vars(),
+            rollup=self._match(TokenType.ROLLUP) and self._parse_wrapped_id_vars(),
         )
 
+    def _parse_grouping_sets(self):
+        if not self._match(TokenType.GROUPING_SETS):
+            return None
+
+        self._match_l_paren()
+        grouping_sets = self._parse_csv(self._parse_grouping_set)
+        self._match_r_paren()
+        return grouping_sets
+
+    def _parse_grouping_set(self):
+        if self._match(TokenType.L_PAREN):
+            grouping_set = self._parse_csv(self._parse_id_var)
+            self._match_r_paren()
+            return self.expression(exp.Tuple, expressions=grouping_set)
+        return self._parse_id_var()
+
     def _parse_having(self):
         if not self._match(TokenType.HAVING):
             return None
@@ -1635,7 +1659,7 @@ class Parser:
         if identifier:
             return identifier
 
-        if any_token:
+        if any_token and self._curr.token_type not in self.SINGLE_TOKENS:
             return self._advance() or exp.Identifier(this=self._prev.text, quoted=False)
 
         return self._match_set(self.ID_VAR_TOKENS) and exp.Identifier(
@@ -1690,10 +1714,7 @@ class Parser:
         if not self._match(TokenType.EXCEPT):
             return None
 
-        self._match_l_paren()
-        columns = self._parse_csv(self._parse_id_var)
-        self._match_r_paren()
-        return columns
+        return self._parse_wrapped_id_vars()
 
     def _parse_replace(self):
         if not self._match(TokenType.REPLACE):
@@ -1728,6 +1749,12 @@ class Parser:
     def _parse_all(self, parse):
         return list(iter(parse, None))
 
+    def _parse_wrapped_id_vars(self):
+        self._match_l_paren()
+        expressions = self._parse_csv(self._parse_id_var)
+        self._match_r_paren()
+        return expressions
+
     def _match(self, token_type):
         if not self._curr:
             return None
